/*
scotty-rev - Scotty REVOLUTION Network Management Dashboard

Authors:
  Thomas Liske <liske@ibh.de>

Copyright Holder:
  2012 - 2013 (C) Thomas Liske [https://fiasko-nw.net/~thomas/tag/scotty]
  2014 - 2016 (C) IBH IT-Service GmbH [http://www.ibh.de/OSS/Scotty]

License:
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this package; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
*/

/*jslint
    devel: true
*/

if (typeof BCP === "undefined") {
    BCP = {};
}
if (typeof BCP.MQTT === "undefined") {
    BCP.MQTT = {};
}

(function ($) {
    "use strict";
    
    var client,
        flashTO,
        reconnTO,
        topics = {};

    this.TO_SCREEN = 30000;
    
    this.bcpReconnect = function () {
        console.debug('Reconnecting...');
        this.bcpConnect();
    };
    
    this.bcpStatus = function (color) {
        $('#bcpHB').css('background', color);
    }.bind(this);

    this.bcpConnect = function () {
        this.bcpStatus('yellow');
        console.debug('Connecting to MQTT broker ' + this.broker_host + ':' + this.broker_port + '...');
        this.client = new Paho.MQTT.Client(this.broker_host, this.broker_port, '', this.clientId);

               
        this.client.disconnect = (function () {
            console.error("Disconnected");
            this.bcpStatus('#7f0000');
        }).bind(this);
        this.client.onConnectionLost = (function (res) {
            this.bcpStatus('#ff0000');
            console.error("Connection Lost: " + res.errorMessage);

            if (this.reconnTO) {
                clearTimeout(this.reconnTO);
            }
            this.bcpStatus('orange');
            this.reconnTO = setTimeout(this.bcpConnect.bind(this), 5000);
        }).bind(this);
        this.client.onMessageArrived = (function (msg) {
            this.bcpStatus('#00ff00');
            setTimeout(function () {
                this.bcpStatus('#007f00');
            }.bind(this), 100);
            
            var topic = msg.destinationName.split('/');
            var event = topic.pop();
            var terminal = topic.pop();

            try {
                BCP.Terminals.bcpUpdate(terminal, event, msg.payloadString);
            } catch(err) {
                console.error("Failure updating terminal " + terminal + " with event " + event + ": " + err.message);
            }

            return 1;
        }).bind(this);

        var me = this;
        this.client.connect({
            onSuccess: (function () {
                console.info('Connected to mqtt://' + this.broker_host + ':' + this.broker_port);
                this.bcpStatus('#7f0000');

                this.client.subscribe('barkery/terminal/+/status');
                this.client.subscribe('barkery/terminal/+/screenshot');
            }).bind(this),
            onFailure: (function (res) {
                if (this.reconnTO) {
                    clearTimeout(this.reconnTO);
                }
                this.bcpStatus('orange');
                this.reconnTO = setTimeout(this.bcpConnect.bind(this), 5000);
            }).bind(this)
        });
    };
    
    this.bcpInit = function (host, port, clientId) {
        if(typeof clientId === "undefined") {
            clientId = 'RND'+Math.floor(Math.random()*16777215).toString(16);
        }
        console.debug('MQTT broker = ' + host + ':' + port);
        console.debug('MQTT clientId = ' + clientId);
        this.broker_host = host;
        this.broker_port = Number(port);
        this.clientId = clientId;
         
        this.bcpConnect();

        var msg = new Paho.MQTT.Message("");
        msg.destinationName = "barkery/terminal/_bcast/cmd/screenshot";
        window.setInterval((function () {
            if(this.client.isConnected) {
                this.client.send(msg);
            }
        }).bind(this), this.TO_SCREEN);
    };
}).call(BCP.MQTT, jQuery);
