/*
scotty-rev - Scotty REVOLUTION Network Management Dashboard

Authors:
  Thomas Liske <liske@ibh.de>

Copyright Holder:
  2012 - 2013 (C) Thomas Liske [https://fiasko-nw.net/~thomas/tag/scotty]
  2014 - 2016 (C) IBH IT-Service GmbH [http://www.ibh.de/OSS/Scotty]

License:
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this package; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
*/

/*jslint
    devel: true
*/

if (typeof BCP === "undefined") {
    BCP = {};
}
if (typeof BCP.Terminals === "undefined") {
    BCP.Terminals = {};
}

(function ($) {
    "use strict";

    this.terminals = {};
    
    this.bcpButton = (function (cl, title, fn) {
        return $("<a>", {
            title: title,
            href: ""
        }).append($("<i>", {
            'class': "fa fa-" + cl
        }));
    }).bind(this);

    this.bcpButtonBar = (function (terminal) {
        return $("<p>", {
            'class': "bcpButtons"
        })
            .append(this.bcpButton('camera', 'Refresh screenshot.'))
            .append(this.bcpButton('spinner', '(Re)load default page.'))
            .append(this.bcpButton('chain', 'Load user supplied URL.'))
            .append(this.bcpButton('refresh', 'Reboot terminal.'))
            .append(this.bcpButton('power-off', 'Power on display via CEC.'))
            .append(this.bcpButton('close', 'Power off display via CEC.'));
    }).bind(this);
    
    this.bcpNewTerminal = (function (terminal) {
        this.terminals[terminal] = {};

        var div = $("<div>", {
            'class': "bcpTerm"
        }).appendTo($("#bcpTerms"));

        var img = $("<img>", {
            'class': "bcpScreen"
        });

        var scrdiv = $("<div>", {
            'class': "bcpScreenDiv"
        }).append(img);

        var statusLine = $("<div>", {
            'class': "bcpStatusLine"
        }).append($("<i>", {
            'class': 'fa fa-keyboard-o'
        }));


        div.append(this.bcpButtonBar(terminal)).append($("<h1>").text(terminal)).append(scrdiv).append(statusLine);
        
        this.terminals[terminal] = {
            div: div[0],
            screen: img[0]
        };
    }).bind(this);
    
    this.bcpTermUpStatus = (function (terminal, status) {
        
    }).bind(this);
    
    this.bcpTermUpScreenshot = (function (terminal, image) {
        this.terminals[terminal]['screen'].src = image;
    }).bind(this);
    
    this.bcpUpdate = (function (terminal, event, json) {
        console.debug("TERM " + terminal + " => " + event);

        if (typeof this.terminals[terminal] === "undefined") {
            this.bcpNewTerminal(terminal);
        }
        
        switch(event) {
            case "status":
                this.bcpTermUpStatus(terminal, json);
                break;
            case "screenshot":
                this.bcpTermUpScreenshot(terminal, json);
                break;
            default:
                console.warn("Unknown event " + event + " for terminal " + terminal + "!");
                break;
        }
    }).bind(this);
    
    this.bcpInit = (function() {
        $("#bcpBCastButtons").append(this.bcpButtonBar('_bcast'));
    }).bind(this);
}).call(BCP.Terminals, jQuery);
